@@ -5,11 +5,10 @@ from zope.interface import implementer
 
 @implementer(INonInstallable)
 class HiddenProfiles(object):
-
     def getNonInstallableProfiles(self):
         """Hide uninstall profile from site-creation and quickinstaller."""
         return [
-            'imio.gdpr:uninstall',
+            "imio.gdpr:uninstall",
         ]
 
 
