@@ -14,29 +14,29 @@ from zope.component import getUtility
 
 def udpate_default_template(context):
     text = get_default_text(api.portal.get())
-    api.portal.set_registry_record('text', text, interface=IGDPRSettings)
+    api.portal.set_registry_record("text", text, interface=IGDPRSettings)
 
 
 def reload_gs_profile(context):
     loadMigrationProfile(
         context,
-        'profile-imio.gdpr:default',
+        "profile-imio.gdpr:default",
     )
 
 
 def add_cookie_policy(context):
     registry = getUtility(IRegistry)
     records = registry.records
-    if 'imio.gdpr.interfaces.IGDPRSettings.cookies_text' in records:
+    if "imio.gdpr.interfaces.IGDPRSettings.cookies_text" in records:
         return
     record = Record(
         field.Text(
-            title=_(u'title_cookies_text', default=u'Cookies text'),
+            title=_("title_cookies_text", default="Cookies text"),
             description=_(
-                u'help_cookies_text',
-                default=u'The text of the Cookies Policy page.'),
+                "help_cookies_text", default="The text of the Cookies Policy page."
+            ),
             required=True,
         ),
-        value=get_default_cookies_text(context)
+        value=get_default_cookies_text(context),
     )
-    records['imio.gdpr.interfaces.IGDPRSettings.cookies_text'] = record
+    records["imio.gdpr.interfaces.IGDPRSettings.cookies_text"] = record
